@@ -79,11 +79,11 @@ class Client:
         response = _casting.cast(method.output, raw)
 
         # The s3.download_fileobj is a special case where the data is written to the
-        # FileObj argument and not returned via an output argument.
+        # Fileobj argument and not returned via an output argument.
         if self._service_name == "s3" and called_method_name == "download_fileobj":
-            buffer: io.BytesIO = request["FileObj"]
+            buffer: io.BytesIO = request["Fileobj"]
             file_obj_data: typing.Union[str, bytes, None] = response.pop(
-                "FileObj", None
+                "Fileobj", None
             )
             if isinstance(file_obj_data, str):
                 file_obj_data = file_obj_data.encode()
