@@ -3,5 +3,5 @@ from lobotomy._services._definitions import Service  # noqa: F401
 
 
 def load_definition(service_name: str) -> "Service":
-    """Loads client definition data for the associated AWS service."""
+    """Load client definition data for the associated AWS service."""
     return Service(service_name)
